@@ -27,7 +27,7 @@
  * list of people on the gedit Team.
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-commands-search.c 5631 2007-06-17 15:07:49Z paolo $
+ * $Id: gedit-commands-search.c 6970 2009-03-21 21:06:49Z icq $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -71,7 +71,7 @@ last_search_data_free (LastSearchData *data)
 {
 	g_free (data->find_text);
 	g_free (data->replace_text);
-	g_free (data);
+	g_slice_free (LastSearchData, data);
 }
 
 static void
@@ -84,14 +84,14 @@ last_search_data_set (LastSearchData    *data,
 	if (str != NULL && *str != '\0')
 	{
 		g_free (data->find_text);
-		data->find_text = g_strdup (str);
+		data->find_text = gedit_utils_unescape_search_text (str);
 	}
 
 	str = gedit_search_dialog_get_replace_text (dialog);
 	if (str != NULL && *str != '\0')
 	{
 		g_free (data->replace_text);
-		data->replace_text = g_strdup (str);
+		data->replace_text = gedit_utils_unescape_search_text (str);
 	}
 
 	data->match_case = gedit_search_dialog_get_match_case (dialog);
@@ -136,7 +136,7 @@ restore_last_searched_data (GeditSearchDialog *dialog,
 
 	if (data == NULL)
 	{
-		data = g_new0 (LastSearchData, 1);
+		data = g_slice_new0 (LastSearchData);
 		last_search_data_set (data, dialog);
 
 		g_object_set_data (G_OBJECT (doc),
