@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-plugins-engine.c 6921 2009-02-25 09:42:39Z pborelli $
+ * $Id: gedit-plugins-engine.c 6986 2009-04-11 14:33:04Z pborelli $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -393,8 +393,12 @@ load_loader (GeditPluginsEngine *engine,
 	path = g_path_get_dirname (filename);
 	base = g_path_get_basename (filename);
 
-	module = gedit_object_module_new (base, path, "register_gedit_plugin_loader");
-	
+	/* for now they are all resident */
+	module = gedit_object_module_new (base,
+					  path,
+					  "register_gedit_plugin_loader",
+					  TRUE);
+
 	g_free (base);
 	g_free (path);
 
