@@ -26,7 +26,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-prefs-manager-app.c 5803 2007-08-15 00:08:37Z paolo $
+ * $Id: gedit-prefs-manager-app.c 6865 2009-01-24 18:02:20Z pborelli $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -43,7 +43,9 @@
 #include "gedit-view.h"
 #include "gedit-window.h"
 #include "gedit-window-private.h"
-#include "gedit-source-style-manager.h"
+#include "gedit-plugins-engine.h"
+#include "gedit-style-scheme-manager.h"
+#include "gedit-dirs.h"
 
 static void gedit_prefs_manager_editor_font_changed	(GConfClient *client,
 							 guint        cnxn_id,
@@ -126,6 +128,11 @@ static void gedit_prefs_manager_auto_save_changed	(GConfClient *client,
 							 GConfEntry  *entry,
 							 gpointer     user_data);
 
+static void gedit_prefs_manager_active_plugins_changed	(GConfClient *client,
+							 guint        cnxn_id, 
+							 GConfEntry  *entry, 
+							 gpointer     user_data);
+
 static void gedit_prefs_manager_lockdown_changed	(GConfClient *client,
 							 guint        cnxn_id,
 							 GConfEntry  *entry,
@@ -139,7 +146,7 @@ static void gedit_prefs_manager_lockdown_changed	(GConfClient *client,
 #define GEDIT_STATE_DEFAULT_SIDE_PANEL_SIZE	200
 #define GEDIT_STATE_DEFAULT_BOTTOM_PANEL_SIZE	140
 
-#define GEDIT_STATE_FILE_LOCATION ".gnome2/gedit-2"
+#define GEDIT_STATE_FILE_LOCATION "gedit-2"
 
 #define GEDIT_STATE_WINDOW_GROUP "window"
 #define GEDIT_STATE_WINDOW_STATE "state"
@@ -158,10 +165,30 @@ static gint window_height = -1;
 static gint window_width = -1;
 static gint side_panel_size = -1;
 static gint bottom_panel_size = -1;
-static gint side_panel_active_page = 0;
-static gint bottom_panel_active_page = 0;
+static gint side_panel_active_page = -1;
+static gint bottom_panel_active_page = -1;
 static gint active_file_filter = -1;
 
+
+static gchar *
+get_state_filename (void)
+{
+	gchar *config_dir;
+	gchar *filename = NULL;
+
+	config_dir = gedit_dirs_get_user_config_dir ();
+
+	if (config_dir != NULL)
+	{
+		filename = g_build_filename (config_dir,
+					     GEDIT_STATE_FILE_LOCATION,
+					     NULL);
+		g_free (config_dir);
+	}
+
+	return filename;
+}
+
 static GKeyFile *
 get_gedit_state_file ()
 {
@@ -169,25 +196,15 @@ get_gedit_state_file ()
 
 	if (state_file == NULL)
 	{
-		const gchar *home;
-		gchar *path;
+		gchar *filename;
 		GError *err = NULL;
 
 		state_file = g_key_file_new ();
 
-		home = g_get_home_dir ();
-		if (home == NULL)
-		{
-			g_warning ("Could not get HOME directory\n");
-			goto out;
-		}
-
-		path = g_build_filename (home,
-					 GEDIT_STATE_FILE_LOCATION,
-					 NULL);
+		filename = get_state_filename ();
 
 		if (!g_key_file_load_from_file (state_file,
-						path,
+						filename,
 						G_KEY_FILE_NONE,
 						&err))
 		{
@@ -197,13 +214,13 @@ get_gedit_state_file ()
 				g_warning ("Could not load gedit state file: %s\n",
 					   err->message);
 			}
+
+			g_error_free (err);
 		}
 
-		g_free (path);
+		g_free (filename);
 	}
 
- out:
-	g_return_val_if_fail (state_file != NULL, NULL);
 	return state_file;
 }
 
@@ -235,8 +252,8 @@ gedit_state_get_int (const gchar *group,
 				   err->message);
 		}
 
-		if (defval > 0)
-			*result = defval;
+		*result = defval;
+		g_error_free (err);
 	}
 	else
 	{
@@ -262,26 +279,30 @@ static gboolean
 gedit_state_file_sync ()
 {
 	GKeyFile *state_file;
-	const gchar *home;
-	gchar *path;
-	gchar *content;
+	gchar *config_dir;
+	gchar *filename = NULL;
+	gchar *content = NULL;
 	gsize length;
+	gint res;
 	GError *err = NULL;
 	gboolean ret = FALSE;
 
 	state_file = get_gedit_state_file ();
 	g_return_val_if_fail (state_file != NULL, FALSE);
 
-	home = g_get_home_dir ();
-	if (home == NULL)
+	config_dir = gedit_dirs_get_user_config_dir ();
+	if (config_dir == NULL)
 	{
-		g_warning ("Could not get HOME directory\n");
+		g_warning ("Could not get config directory\n");
 		return ret;
 	}
 
-	path = g_build_filename (home,
-				 GEDIT_STATE_FILE_LOCATION,
-				 NULL);
+	res = g_mkdir_with_parents (config_dir, 0755);
+	if (res < 0)
+	{
+		g_warning ("Could not create config directory\n");
+		goto out;
+	}
 
 	content = g_key_file_to_data (state_file,
 				      &length,
@@ -294,24 +315,31 @@ gedit_state_file_sync ()
 		goto out;
 	}
 
-	if ((content != NULL) &&
-	    (!g_file_set_contents (path,
-				   content,
-				   length,
-				   &err)))
+	if (content != NULL)
 	{
-		g_warning ("Could not write gedit state file: %s\n",
-			   err->message);
-		goto out;
+		filename = get_state_filename ();
+		if (!g_file_set_contents (filename,
+					  content,
+					  length,
+					  &err))
+		{
+			g_warning ("Could not write gedit state file: %s\n",
+				   err->message);
+			goto out;
+		}
 	}
 
 	ret = TRUE;
 
  out:
-	g_free (content);
-	g_free (path);
+	if (err != NULL)
+		g_error_free (err);
 
-	return TRUE;
+	g_free (config_dir);
+	g_free (filename);
+	g_free (content);
+
+	return ret;
 }
 
 /* Window state */
@@ -448,11 +476,11 @@ gedit_prefs_manager_side_panel_size_can_set (void)
 gint
 gedit_prefs_manager_get_side_panel_active_page (void)
 {
-	if (side_panel_active_page == 0)
+	if (side_panel_active_page == -1)
 	{
 		gedit_state_get_int (GEDIT_STATE_WINDOW_GROUP,
 				     GEDIT_STATE_SIDE_PANEL_ACTIVE_PAGE,
-				     -1,
+				     0,
 				     &side_panel_active_page);
 	}
 
@@ -521,11 +549,11 @@ gedit_prefs_manager_bottom_panel_size_can_set (void)
 gint
 gedit_prefs_manager_get_bottom_panel_active_page (void)
 {
-	if (bottom_panel_active_page == 0)
+	if (bottom_panel_active_page == -1)
 	{
 		gedit_state_get_int (GEDIT_STATE_WINDOW_GROUP,
 				     GEDIT_STATE_BOTTOM_PANEL_ACTIVE_PAGE,
-				     -1,
+				     0,
 				     &bottom_panel_active_page);
 	}
 
@@ -603,6 +631,11 @@ gedit_prefs_manager_app_init (void)
 				GPM_PREFS_DIR,
 				GCONF_CLIENT_PRELOAD_RECURSIVE,
 				NULL);
+
+		gconf_client_add_dir (gedit_prefs_manager->gconf_client,
+				GPM_PLUGINS_DIR,
+				GCONF_CLIENT_PRELOAD_RECURSIVE,
+				NULL);
 		
 		gconf_client_add_dir (gedit_prefs_manager->gconf_client,
 				GPM_LOCKDOWN_DIR,
@@ -688,7 +721,12 @@ gedit_prefs_manager_app_init (void)
 				GPM_SAVE_DIR,
 				gedit_prefs_manager_auto_save_changed,
 				NULL, NULL, NULL);
-		
+
+		gconf_client_notify_add (gedit_prefs_manager->gconf_client,
+				GPM_ACTIVE_PLUGINS,
+				gedit_prefs_manager_active_plugins_changed,
+				NULL, NULL, NULL);
+
 		gconf_client_notify_add (gedit_prefs_manager->gconf_client,
 				GPM_LOCKDOWN_DIR,
 				gedit_prefs_manager_lockdown_changed,
@@ -762,7 +800,7 @@ gedit_prefs_manager_editor_font_changed (GConfClient *client,
 	{
 		/* Note: we use def=FALSE to avoid GeditView to query gconf */
 		gedit_view_set_font (GEDIT_VIEW (l->data), FALSE,  font);
-		gtk_source_view_set_tabs_width (GTK_SOURCE_VIEW (l->data), ts);
+		gtk_source_view_set_tab_width (GTK_SOURCE_VIEW (l->data), ts);
 
 		l = l->next;
 	}
@@ -808,7 +846,7 @@ gedit_prefs_manager_system_font_changed (GConfClient *client,
 		/* Note: we use def=FALSE to avoid GeditView to query gconf */
 		gedit_view_set_font (GEDIT_VIEW (l->data), FALSE, font);
 
-		gtk_source_view_set_tabs_width (GTK_SOURCE_VIEW (l->data), ts);
+		gtk_source_view_set_tab_width (GTK_SOURCE_VIEW (l->data), ts);
 		l = l->next;
 	}
 
@@ -829,24 +867,24 @@ gedit_prefs_manager_tabs_size_changed (GConfClient *client,
 
 	if (strcmp (entry->key, GPM_TABS_SIZE) == 0)
 	{
-		gint tabs_size;
+		gint tab_width;
 		GList *views;
 		GList *l;
-		
+
 		if (entry->value->type == GCONF_VALUE_INT)
-			tabs_size = gconf_value_get_int (entry->value);
+			tab_width = gconf_value_get_int (entry->value);
 		else
-			tabs_size = GPM_DEFAULT_TABS_SIZE;
+			tab_width = GPM_DEFAULT_TABS_SIZE;
 	
-		tabs_size = CLAMP (tabs_size, 1, 24);
+		tab_width = CLAMP (tab_width, 1, 24);
 
 		views = gedit_app_get_views (gedit_app_get_default ());
 		l = views;
 
 		while (l != NULL)
 		{
-			gtk_source_view_set_tabs_width (GTK_SOURCE_VIEW (l->data), 
-							tabs_size);
+			gtk_source_view_set_tab_width (GTK_SOURCE_VIEW (l->data), 
+						       tab_width);
 
 			l = l->next;
 		}
@@ -858,7 +896,7 @@ gedit_prefs_manager_tabs_size_changed (GConfClient *client,
 		gboolean enable;
 		GList *views;
 		GList *l;
-		
+
 		if (entry->value->type == GCONF_VALUE_BOOL)
 			enable = gconf_value_get_bool (entry->value);	
 		else
@@ -1039,8 +1077,8 @@ gedit_prefs_manager_bracket_matching_changed (GConfClient *client,
 
 		while (l != NULL)
 		{
-			gtk_source_buffer_set_check_brackets (GTK_SOURCE_BUFFER (l->data),
-							      enable);
+			gtk_source_buffer_set_highlight_matching_brackets (GTK_SOURCE_BUFFER (l->data),
+									   enable);
 
 			l = l->next;
 		}
@@ -1154,8 +1192,8 @@ gedit_prefs_manager_right_margin_changed (GConfClient *client,
 
 		while (l != NULL)
 		{
-			gtk_source_view_set_margin (GTK_SOURCE_VIEW (l->data),
-						    pos);
+			gtk_source_view_set_right_margin_position (GTK_SOURCE_VIEW (l->data),
+								   pos);
 
 			l = l->next;
 		}
@@ -1178,8 +1216,8 @@ gedit_prefs_manager_right_margin_changed (GConfClient *client,
 
 		while (l != NULL)
 		{
-			gtk_source_view_set_show_margin (GTK_SOURCE_VIEW (l->data),
-							 display);
+			gtk_source_view_set_show_right_margin (GTK_SOURCE_VIEW (l->data),
+							       display);
 
 			l = l->next;
 		}
@@ -1275,8 +1313,8 @@ gedit_prefs_manager_syntax_hl_enable_changed (GConfClient *client,
 		{
 			g_return_if_fail (GTK_IS_SOURCE_BUFFER (l->data));
 
-			gtk_source_buffer_set_highlight (GTK_SOURCE_BUFFER (l->data),
-							 enable);
+			gtk_source_buffer_set_highlight_syntax (GTK_SOURCE_BUFFER (l->data),
+								enable);
 
 			l = l->next;
 		}
@@ -1370,16 +1408,19 @@ gedit_prefs_manager_source_style_scheme_changed (GConfClient *client,
 
 		g_free (old_scheme);
 		old_scheme = g_strdup (scheme);
-		
-		style = gtk_source_style_manager_get_scheme (gedit_get_source_style_manager (), 
-							     scheme);
+
+		style = gtk_source_style_scheme_manager_get_scheme (
+				gedit_get_style_scheme_manager (),
+				scheme);
 
 		if (style == NULL)
 		{
 			g_warning ("Default style scheme '%s' not found, falling back to 'classic'", scheme);
 			
-			style = gtk_source_style_manager_get_scheme (gedit_get_source_style_manager (), 
-								     "classic");
+			style = gtk_source_style_scheme_manager_get_scheme (
+				gedit_get_style_scheme_manager (),
+				"classic");
+
 			if (style == NULL) 
 			{
 				g_warning ("Style scheme 'classic' cannot be found, check your GtkSourceView installation.");
@@ -1511,6 +1552,31 @@ gedit_prefs_manager_auto_save_changed (GConfClient *client,
 	}
 }
 
+static void 
+gedit_prefs_manager_active_plugins_changed (GConfClient *client,
+					    guint        cnxn_id,
+					    GConfEntry  *entry,
+					    gpointer     user_data)
+{
+	gedit_debug (DEBUG_PREFS);
+
+	g_return_if_fail (entry->key != NULL);
+	g_return_if_fail (entry->value != NULL);
+
+	if (strcmp (entry->key, GPM_ACTIVE_PLUGINS) == 0)
+	{
+		if ((entry->value->type == GCONF_VALUE_LIST) && 
+		    (gconf_value_get_list_type (entry->value) == GCONF_VALUE_STRING))
+		{
+			GeditPluginsEngine *engine;
+
+			engine = gedit_plugins_engine_get_default ();
+
+			gedit_plugins_engine_active_plugins_changed (engine);
+		}
+	}
+}
+
 static void
 gedit_prefs_manager_lockdown_changed (GConfClient *client,
 				      guint        cnxn_id,
