@@ -27,7 +27,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-utils.c 6727 2008-12-25 21:02:48Z pborelli $
+ * $Id: gedit-utils.c 6928 2009-03-01 15:26:54Z pborelli $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -620,6 +620,8 @@ gedit_utils_make_valid_utf8 (const char *name)
 	const char *remainder, *invalid;
 	int remaining_bytes, valid_bytes;
 
+	g_return_val_if_fail (name != NULL, NULL);
+
 	string = NULL;
 	remainder = name;
 	remaining_bytes = strlen (name);
@@ -659,7 +661,9 @@ gedit_utils_uri_get_dirname (const gchar *uri)
 	gchar *res;
 	gchar *str;
 
-	// CHECK: does it work with uri chaining? - Paolo
+	g_return_val_if_fail (uri != NULL, NULL);
+
+	/* CHECK: does it work with uri chaining? - Paolo */
 	str = g_path_get_dirname (uri);
 	g_return_val_if_fail (str != NULL, ".");
 
@@ -677,6 +681,71 @@ gedit_utils_uri_get_dirname (const gchar *uri)
 	return res;
 }
 
+/**
+ * gedit_utils_location_get_dirname_for_display
+ * @file: the location
+ *
+ * Returns a string suitable to be displayed in the UI indicating
+ * the name of the directory where the file is located.
+ * For remote files it may also contain the hostname etc.
+ * For local files it tries to replace the home dir with ~.
+ *
+ * Returns: a string to display the dirname
+ */
+gchar *
+gedit_utils_location_get_dirname_for_display (GFile *location)
+{
+	gchar *uri;
+	gchar *res;
+	GMount *mount;
+
+	g_return_val_if_fail (location != NULL, NULL);
+
+	/* we use the parse name, that is either the local path
+	 * or an uri but which is utf8 safe */
+	uri = g_file_get_parse_name (location);
+
+	/* FIXME: this is sync... is it a problem? */
+	mount = g_file_find_enclosing_mount (location, NULL, NULL);
+	if (mount != NULL)
+	{
+		gchar *mount_name;
+		gchar *path;
+
+		mount_name = g_mount_get_name (mount);
+		g_object_unref (mount);
+
+		/* obtain the "path" patrt of the uri */
+		if (gedit_utils_decode_uri (uri,
+					    NULL, NULL,
+					    NULL, NULL,
+					    &path))
+		{
+			gchar *dirname;
+			
+			dirname = gedit_utils_uri_get_dirname (path);
+			res = g_strdup_printf ("%s %s", mount_name, dirname);
+
+			g_free (path);
+			g_free (dirname);
+			g_free (mount_name);
+		}
+		else
+		{
+			res = mount_name;
+		}
+	}
+	else
+	{
+		/* fallback for local files or uris without mounts */
+		res = gedit_utils_uri_get_dirname (uri);
+	}
+
+	g_free (uri);
+
+	return res;
+}
+
 gchar *
 gedit_utils_replace_home_dir_with_tilde (const gchar *uri)
 {
@@ -947,8 +1016,7 @@ gedit_utils_is_valid_uri (const gchar *uri)
 }
 
 static GtkWidget *
-handle_builder_error (const gchar *message,
-		      ...)
+handle_builder_error (const gchar *message, ...)
 {
 	GtkWidget *label;
 	gchar *msg;
@@ -956,16 +1024,18 @@ handle_builder_error (const gchar *message,
 	va_list args;
 
 	va_start (args, message);
-	va_arg (args, const gchar *);
 	msg_plain = g_strdup_vprintf (message, args);
+	va_end (args);
+
+	label = gtk_label_new (NULL);
+	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 
 	msg = g_strconcat ("<span size=\"large\" weight=\"bold\">",
-			msg_plain, "</span>\n\n",
-			_("Please check your installation."), NULL);
-	label = gtk_label_new (msg);
+			   msg_plain, "</span>\n\n",
+			   _("Please check your installation."),
+			   NULL);
 
-	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+	gtk_label_set_markup (GTK_LABEL (label), msg);
 
 	g_free (msg_plain);
 	g_free (msg);
@@ -1147,11 +1217,11 @@ gedit_utils_basename_for_display (gchar const *uri)
 	gchar *name;
 	GFile *gfile;
 	gchar *hn;
-	
+
 	g_return_val_if_fail (uri != NULL, NULL);
-	
+
 	gfile = g_file_new_for_uri (uri);
-	
+
 	/* First, try to query the display name, but only on local files */
 	if (g_file_has_uri_scheme (gfile, "file"))
 	{
@@ -1198,11 +1268,16 @@ gedit_utils_basename_for_display (gchar const *uri)
 	{
 		/* display '/ on <host>' using the decoded host */
 		gchar *hn_utf8;
-		hn_utf8 = gedit_utils_make_valid_utf8 (hn);
-		
+
+		if  (hn != NULL)
+			hn_utf8 = gedit_utils_make_valid_utf8 (hn);
+		else
+			/* we should never get here */
+			hn_utf8 = g_strdup ("?");
+
 		/* Translators: '/ on <remote-share>' */
 		name = g_strdup_printf (_("/ on %s"), hn_utf8);
-		
+
 		g_free (hn_utf8);
 		g_free (hn);
 	}
