@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-taglist-plugin-parser.c 6745 2008-12-28 21:27:48Z icq $
+ * $Id: gedit-taglist-plugin-parser.c 6929 2009-03-01 17:04:09Z pborelli $
  */
 
 /* FIXME: we should rewrite the parser to avoid using DOM */
@@ -34,10 +34,7 @@
 #include <config.h>
 #endif
 
-#include <dirent.h> 
 #include <string.h>
-#include <errno.h>
-
 #include <libxml/parser.h>
 #include <glib.h>
 #include <glib/gi18n.h>
@@ -184,13 +181,12 @@ parse_tag_group (TagGroup *tg, const gchar* fn, xmlDocPtr doc,
 	return TRUE;
 }
 
-
 static TagGroup*
 get_tag_group (const gchar* filename, xmlDocPtr doc, 
 		 xmlNsPtr ns, xmlNodePtr cur) 
 {
 	TagGroup *tag_group;
-	gchar *sort_str;
+	xmlChar *sort_str;
 	gboolean sort = FALSE;
 
 	tag_group = g_new0 (TagGroup, 1);
@@ -198,16 +194,18 @@ get_tag_group (const gchar* filename, xmlDocPtr doc,
 	/* Get TagGroup name */
 	tag_group->name = xmlGetProp (cur, (const xmlChar *) "name");
 
-	sort_str = (gchar *)xmlGetProp (cur, (const xmlChar *) "sort");
-	
+	sort_str = xmlGetProp (cur, (const xmlChar *) "sort");
+
 	if ((sort_str != NULL) &&
-	    ((g_ascii_strcasecmp (sort_str, "yes") == 0) ||
-	     (g_ascii_strcasecmp (sort_str, "true") == 0) ||
-	     (g_ascii_strcasecmp (sort_str, "1") == 0)))
+	    ((xmlStrcasecmp (sort_str, (const xmlChar *) "yes") == 0) ||
+	     (xmlStrcasecmp (sort_str, (const xmlChar *) "true") == 0) ||
+	     (xmlStrcasecmp (sort_str, (const xmlChar *) "1") == 0)))
 	{
 		sort = TRUE;
 	}
-	
+
+	xmlFree(sort_str);
+
 	if (tag_group->name == NULL)
 	{
 		/* Error: No name */
@@ -486,7 +484,6 @@ parse_taglist_file (const gchar* filename)
 	return taglist;
 }
 
-
 static void
 free_tag (Tag *tag)
 {
@@ -509,21 +506,20 @@ free_tag (Tag *tag)
 static void
 free_tag_group (TagGroup *tag_group)
 {
+	GList *l;
+
 	gedit_debug_message (DEBUG_PLUGINS, "Tag group: %s", tag_group->name);
 
 	g_return_if_fail (tag_group != NULL);
 
 	free (tag_group->name);
 
-	while (tag_group->tags)
+	for (l = tag_group->tags; l != NULL; l = g_list_next (l))
 	{
-		free_tag ((Tag *)tag_group->tags->data);
-
-		tag_group->tags = g_list_next (tag_group->tags);
+		free_tag ((Tag *) l->data);
 	}
 
 	g_list_free (tag_group->tags);
-	
 	g_free (tag_group);
 
 	gedit_debug_message (DEBUG_PLUGINS, "END");
@@ -532,28 +528,26 @@ free_tag_group (TagGroup *tag_group)
 void
 free_taglist (void)
 {
+	GList *l;
+
 	gedit_debug_message (DEBUG_PLUGINS, "ref_count: %d", taglist_ref_count);
-	
+
 	if (taglist == NULL)
 		return;
-		
+
 	g_return_if_fail (taglist_ref_count > 0);
 
 	--taglist_ref_count;
 	if (taglist_ref_count > 0)
 		return;
-		
-	while (taglist->tag_groups)
-	{
-		free_tag_group ((TagGroup *)taglist->tag_groups->data);
 
-		taglist->tag_groups = g_list_next (taglist->tag_groups);
+	for (l = taglist->tag_groups; l != NULL; l = g_list_next (l))
+	{
+		free_tag_group ((TagGroup *) l->data);
 	}
 
 	g_list_free (taglist->tag_groups);
-	
 	g_free (taglist);
-
 	taglist = NULL;
 
 	gedit_debug_message (DEBUG_PLUGINS, "Really freed");
@@ -562,30 +556,32 @@ free_taglist (void)
 static TagList * 
 parse_taglist_dir (const gchar *dir)
 {
-	DIR *d;
-	struct dirent *e;
+	GError *error = NULL;
+	GDir *d;
+	const gchar *dirent;
 
 	gedit_debug_message (DEBUG_PLUGINS, "DIR: %s", dir);
 
-	d = opendir (dir);
-	
-	if (d == NULL)
-	{		
-		gedit_debug_message (DEBUG_PLUGINS, "%s", strerror (errno));
+	d = g_dir_open (dir, 0, &error);
+	if (!d)
+	{
+		gedit_debug_message (DEBUG_PLUGINS, "%s", error->message);
+		g_error_free (error);
 		return taglist;
 	}
-	
-	while ((e = readdir (d)) != NULL)
+
+	while ((dirent = g_dir_read_name (d)))
 	{
-		if (strncmp (e->d_name + strlen (e->d_name) - 5, ".tags", 5) == 0 ||
-		    strncmp (e->d_name + strlen (e->d_name) - 8, ".tags.gz", 8) == 0)
+		if (g_str_has_suffix (dirent, ".tags") ||
+		    g_str_has_suffix (dirent, ".tags.gz"))
 		{
-			gchar *tags_file = g_build_filename (dir, e->d_name, NULL);
+			gchar *tags_file = g_build_filename (dir, dirent, NULL);
 			parse_taglist_file (tags_file);
 			g_free (tags_file);
 		}
 	}
-	closedir (d);
+
+	g_dir_close (d);
 
 	return taglist;
 }
